@@ -4,11 +4,9 @@
 #############################################################################
 
 package Graph::Easy::As_svg;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::As_svg::VERSION = '0.26';
 use 5.010;
 
-our $VERSION = '0.23';
 
 use strict;
 use warnings;
@@ -16,7 +14,7 @@ use utf8;
 
 sub _text_length
   {
-  # Take a string, and return it's length, based on the font-size and the
+  # Take a string, and return its length, based on the font-size and the
   # contents ("iii" is shorter than "WWW")
   my ($em, $text) = @_;
 
@@ -140,8 +138,7 @@ sub _sprintf
 #############################################################################
 
 package Graph::Easy;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::VERSION = '0.26';
 use strict;
 
 BEGIN
@@ -728,8 +725,7 @@ EOSVG
 #############################################################################
 
 package Graph::Easy::Node::Cell;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Node::Cell::VERSION = '0.26';
 sub as_svg
   {
   '';
@@ -748,8 +744,7 @@ sub _correct_size_svg
 #############################################################################
 
 package Graph::Easy::Group::Cell;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Group::Cell::VERSION = '0.26';
 sub as_svg
   {
   my ($self,$x, $y, $indent) = @_;
@@ -830,8 +825,7 @@ sub _svg_background
 #############################################################################
 
 package Graph::Easy::Group;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Group::VERSION = '0.26';
 sub as_svg
   {
   # output all cells of the group as svg
@@ -852,8 +846,7 @@ sub as_svg
 #############################################################################
 
 package Graph::Easy::Edge;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Edge::VERSION = '0.26';
 use Graph::Easy::Edge::Cell qw/EDGE_HOLE/;
 
 sub as_svg
@@ -887,8 +880,7 @@ sub as_svg
 #############################################################################
 
 package Graph::Easy::Node::Empty;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Node::Empty::VERSION = '0.26';
 sub as_svg
   {
   # empty nodes are not rendered at all
@@ -899,8 +891,7 @@ sub as_svg
 #############################################################################
 
 package Graph::Easy::Node;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Node::VERSION = '0.26';
 BEGIN
   {
   *_sprintf = \&Graph::Easy::As_svg::_sprintf;
@@ -1471,8 +1462,7 @@ sub _correct_size_svg
 #############################################################################
 
 package Graph::Easy::Edge::Cell;
-our $AUTHORITY = 'cpan:SHLOMIF';
-
+$Graph::Easy::Edge::Cell::VERSION = '0.26';
 BEGIN
   {
   *_sprintf = \&Graph::Easy::As_svg::_sprintf;
@@ -2135,7 +2125,7 @@ Graph::Easy::As_svg - Output a Graph::Easy as Scalable Vector Graphics (SVG)
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -2162,7 +2152,7 @@ X<grafics>
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 EXPORT
 
@@ -2195,8 +2185,7 @@ This is free software, licensed under:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Graph-Easy-As_svg or by
-email to bug-graph-easy-as_svg@rt.cpan.org.
+https://github.com/shlomif/Graph-Easy-As_svg/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
